/*******************************************************************************
 *
 * blueMarine - open source photo workflow
 * =======================================
 *
 * Copyright (C) 2003-2009 by Fabrizio Giudici
 * Project home page: http://bluemarine.tidalwave.it
 *
 *******************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 *
 *******************************************************************************
 *
 * $Id$
 *
 ******************************************************************************/
package it.tidalwave.metadata.text;

import java.text.DecimalFormat;
import java.text.FieldPosition;
import javax.annotation.CheckForNull;
import javax.annotation.Nonnull;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class ApertureFormat extends DecimalFormat
  {
    public static enum F
      {
        STANDARD("f"),
        UNICODE("\u0192");

        @Nonnull
        private final String text;
        
        private F (@Nonnull final String text)
          {
            this.text = text;    
          }

        @Nonnull
        public String getText()
          {
            return text;    
          }
      }
    
    private static final long serialVersionUID = 3453452345876458L;

    private F f;

    public ApertureFormat() 
      {
        this(F.STANDARD);
      }

    public ApertureFormat (@Nonnull final F f)
      {
        this.f = f;
      }

    @Nonnull
    public F getF() 
      {
        return f;
      }

    public void setF (@Nonnull final F f)
      {
        this.f = f;
      }
    
    @Override
    @Nonnull
    public StringBuffer format (double number, 
                                @Nonnull final StringBuffer toAppendTo,
                                @Nonnull final FieldPosition pos)
      {
        toAppendTo.append(String.format("%s/%.1f", f.getText(), number).replaceAll(".0$", ""));
        return toAppendTo;
      }

    @Override
    @Nonnull
    public Number parse (@CheckForNull String s)
      {
        if ((s == null) || s.trim().equals(""))
          {
            return Integer.valueOf(-1);
          }

        else
          {
            return Double.valueOf(s.replaceAll(String.format("^%s/", f.getText()), "").trim());
          }
      }
  }
